@@ -1,6 +1,4 @@
-/* $Id: eyes.c 2397 2007-01-17 17:46:35Z nick $
- * 
- * Copyright (c) Benedikt Meurer <benedikt.meurer@unix-ag.uni-siegen.de>>
+/* Copyright (c) Benedikt Meurer <benedikt.meurer@unix-ag.uni-siegen.de>>
  * Copyright (c) Danny Milosavljevic <danny_milo@gmx.net>
  * Copyright (c) Dave Camp
  * Copyright (c) Davyd Madeley  <davyd@madeley.id.au>
@@ -32,6 +30,7 @@
 #include <sys/types.h>
 #include <dirent.h>
 #include <string.h>
+#include <stdlib.h>
 
 #include <libxfce4util/libxfce4util.h>
 #include <libxfcegui4/libxfcegui4.h>
